#!/bin/bash
set -euo pipefail

# Get script directory - handle different execution contexts
if [ -n "${BASH_SOURCE[0]}" ]; then
    SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )"
else
    SCRIPT_DIR="$( cd "$( dirname "$0" )" &> /dev/null && pwd )"
fi
PROJECT="$(basename "$(dirname "${SCRIPT_DIR}")")"


# Debug output for CI
echo "${PROJECT} build script running from: ${SCRIPT_DIR}"

mkdir -p "${SCRIPT_DIR}/build"
mkdir -p "${SCRIPT_DIR}/output"

# Run build in container with mounted directories
docker run --rm \
  --user "$(id -u):$(id -g)" \
  -v "${SCRIPT_DIR}:/app" \
  -e CMAKE_BUILD_TYPE="${CMAKE_BUILD_TYPE:-Debug}" \
  gitea.jde.nz/public/dropshell-build-base:latest \
  bash -c "
    cd /app && ls -la && \
    cmake -G Ninja -S /app -B /app/build \
      -DCMAKE_BUILD_TYPE=\${CMAKE_BUILD_TYPE} \
      -DPROJECT_NAME=${PROJECT} && \
    cmake --build /app/build && \
    cp /app/build/${PROJECT} /app/output/
  "
